@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -78,6 +78,8 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
     QString userIdTooltip = tr("Your address, like username@pumpserver.org");
     userIdLineEdit->setPlaceholderText(userIdTooltip);
     userIdLineEdit->setToolTip("<b></b>" + userIdTooltip); // HTMLized for wordwrap
+    connect(userIdLineEdit, SIGNAL(returnPressed()),
+            this, SLOT(askForToken()));
 
     getVerifierButton = new QPushButton(QIcon::fromTheme("object-unlocked"),
                                         tr("Get &Verifier Code"),
@@ -111,13 +113,17 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
                                                   QIcon(":/images/button-password.png"))
                                  .pixmap(64,64)
                                  .scaledToWidth(64, Qt::SmoothTransformation));
+
     verifierLabel = new QLabel("<b>" + tr("Verifier code:") + "</b>",
                                this);
-    verifierLineEdit = new QLineEdit(this);
+
     QString verifierTooltip = tr("Enter or paste the verifier code provided "
                                  "by your Pump server here");
+    verifierLineEdit = new QLineEdit(this);
     verifierLineEdit->setPlaceholderText(verifierTooltip);
     verifierLineEdit->setToolTip("<b></b>" + verifierTooltip);
+    connect(verifierLineEdit, SIGNAL(returnPressed()),
+            this, SLOT(setVerifierCode()));
 
 
     authorizeApplicationButton = new QPushButton(QIcon::fromTheme("security-high"),
@@ -209,23 +215,23 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
     mainLayout->addWidget(unlockButton, 0, Qt::AlignHCenter);
 
     mainLayout->addWidget(helpMessage1Label, 6);
-    mainLayout->addSpacing(8);
+    mainLayout->addSpacing(2);
     mainLayout->addStretch(1);
     mainLayout->addLayout(idLayout, 2);
-    mainLayout->addSpacing(16);
+    mainLayout->addSpacing(4);
     mainLayout->addStretch(1);
     mainLayout->addWidget(separatorLine);
     mainLayout->addStretch(1);
-    mainLayout->addSpacing(16);
+    mainLayout->addSpacing(4);
     mainLayout->addWidget(helpMessage2Label, 2);
-    mainLayout->addSpacing(8);
+    mainLayout->addSpacing(2);
     mainLayout->addStretch(1);
     mainLayout->addLayout(verifierLayout, 2);
     mainLayout->addWidget(errorsLabel,              1, Qt::AlignCenter);
-    mainLayout->addSpacing(2);
+    mainLayout->addSpacing(1);
     mainLayout->addWidget(authorizationStatusLabel, 1, Qt::AlignCenter);
     mainLayout->addStretch(2);
-    mainLayout->addSpacing(20);
+    mainLayout->addSpacing(8);
     mainLayout->addLayout(buttonsLayout, 1);
     this->setLayout(mainLayout);
 
@@ -318,7 +324,9 @@ void AccountDialog::askForToken()
     }
     else // userID does not match user@hostname.domain
     {
-        this->errorsLabel->setText("[ " + tr("Your Pump address is invalid") + " ]");
+        this->errorsLabel->setText("[ "
+                                   + tr("Your Pump address is invalid")
+                                   + " ]");
         qDebug() << "userID is invalid!";
     }
 }
