@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -133,7 +133,8 @@ Composer::Composer(GlobalObject *globalObject, bool forPublisher,
     toolsButton = new QPushButton(QIcon::fromTheme("format-list-ordered",
                                                    QIcon(":/images/button-configure.png")),
                                   tr("&Format",
-                                     "Button for text formatting and related options"));
+                                     "Button for text formatting and related options"),
+                                  this);
     toolsButton->setMenu(toolsMenu);
     toolsButton->setToolTip("<b></b>"
                             + tr("Text Formatting Options"));
@@ -426,89 +427,109 @@ void Composer::contextMenuEvent(QContextMenuEvent *event)
 
 
 /*
- * Intervene when pasting, so we can turn links into real HTML links
+ * Intervene when pasting, so we can turn link-looking text into real
+ * HTML links, and turn direct links to images into embedded images
  *
  */
 void Composer::insertFromMimeData(const QMimeData *source)
 {
-    if (source->hasHtml())
-    {
-        // It's rich text, so just paste it as is
-        QTextEdit::insertFromMimeData(source);
-    }
-    else
-    {
-        QString pastedText = source->text().trimmed();
+    // First, check if it's just a link to an image, to offer embedding it
+    QString pastedText = source->text().trimmed();
 
-        if (pastedText.startsWith("http://")
-         || pastedText.startsWith("https://"))
+    if (pastedText.startsWith("http://")
+     || pastedText.startsWith("https://"))
+    {
+        // If link looks like an image, ask the user how to insert it
+        if (pastedText.endsWith(".png", Qt::CaseInsensitive)
+         || pastedText.endsWith(".jpg", Qt::CaseInsensitive)
+         || pastedText.endsWith(".jpeg", Qt::CaseInsensitive)
+         || pastedText.endsWith(".gif", Qt::CaseInsensitive))
         {
-            int insertionType = 1;
-
-            // If link looks like an image, ask the user how to insert it
-            if (pastedText.endsWith(".png", Qt::CaseInsensitive)
-             || pastedText.endsWith(".jpg", Qt::CaseInsensitive)
-             || pastedText.endsWith(".jpeg", Qt::CaseInsensitive)
-             || pastedText.endsWith(".gif", Qt::CaseInsensitive))
-            {
-                insertionType = QMessageBox::question(this,
-                                             tr("Insert as image?"),
-                                             tr("The link you are pasting seems to "
-                                                "point to an image.") + "\n",
-                                             tr("Insert as visible image"), // Default option (enter)
-                                             tr("Insert as link"),  // ESC option
-                                             "", 0, 1);
-            }
+            int insertionType= QMessageBox::question(this,
+                                            tr("Insert as image?"),
+                                            tr("The link you are pasting "
+                                               "seems to point to an image.")
+                                            + "\n\n\n",
+                                            tr("Insert as visible image"), // Default option (Enter)
+                                            tr("Insert as link"),          // ESC option
+                                            "", 0, 1);
 
             if (insertionType == 0) // Default button, insert as image
             {
-                this->insertHtml("<img src=\"" + pastedText + "\" />");
-            }
-            else
-            {
-                this->insertLink(pastedText);
-            }
-        }
-        else
-        {
-            if (pastedText.contains("://")) // Probably contains links
-            {
-                qDebug() << "Looking for URL's to htmlize";
-
-                QRegExp regExp("(http|https|ftp)://(.*)(\\s|$)");
-                regExp.setMinimal(true);
-
-                QString link;
-                int matchedLength = 0;
-                int stringPos = 0;
-                while (matchedLength != -1)
-                {
-                    stringPos = regExp.indexIn(pastedText, stringPos);
-                    matchedLength = regExp.matchedLength();
-
-                    qDebug() << regExp.capturedTexts();
-                    link = regExp.cap(0);
-                    QString htmlLink;
-                    if (!link.isEmpty()) // if not an empty string, replace HTML
-                    {
-                        htmlLink = "<a href=\"" + link +  "\">" + link + "</a>";
-                        pastedText.replace(stringPos, matchedLength, htmlLink);
-                    }
-
-                    stringPos += htmlLink.length();
-                }
-
-                pastedText.replace("\n", "<br>");
-
-                this->insertHtml(pastedText + "&nbsp;");
-            }
-            else  // Just paste original contents
-            {
-                qDebug() << "direct paste";
-                QTextEdit::insertFromMimeData(source);
+                this->insertHtml("<img src=\"" + pastedText + "\" />"
+                                 "<br/><br/>");
+                return;
             }
         }
     }
+
+    // If it wasn't just an image link, or offer to embed was rejected, continue
+
+    QTextDocument textDocument;
+    if (source->hasHtml())
+    {
+        textDocument.setHtml(source->html());
+        qDebug() << "Parsing pasted RICH (HTML) text for links...";
+    }
+    else
+    {
+        textDocument.setPlainText(source->text().trimmed());
+        qDebug() << "Parsing pasted PLAIN text for links...";
+    }
+
+
+    QTextCursor cursor = QTextCursor(&textDocument);
+
+    do
+    {
+        cursor.select(QTextCursor::WordUnderCursor);
+
+        QString currentWord = cursor.selection().toPlainText();
+
+        qDebug() << "WORD:" << currentWord;
+
+        if (currentWord == "http" || currentWord == "https"
+         || currentWord == "ftp"  || currentWord == "sftp")
+        {
+            qDebug() << "Text might be a link";
+
+            qDebug() << "Cursor is anchor? " << cursor.charFormat().isAnchor();
+            if (!cursor.charFormat().isAnchor())
+            {
+                qDebug() << "URL-looking text which isn't a link; "
+                            "Replacing with proper link!";
+
+                // Select text until end of pasted text, or a space/line break
+                while (cursor.movePosition(QTextCursor::NextCharacter,
+                                           QTextCursor::KeepAnchor))
+                {
+                    if (textDocument.characterAt(cursor.position()).isSpace())
+                    {
+                        break;
+                    }
+                }
+
+                QString linkFound = cursor.selection().toPlainText();
+
+                if (linkFound.startsWith("http://")
+                 || linkFound.startsWith("https://")
+                 || linkFound.startsWith("ftp://")
+                 || linkFound.startsWith("sftp://"))
+                {
+                    // Turn current selection into a link to the same as the visible text
+                    QTextCharFormat format = cursor.charFormat();
+                    format.setAnchorHref(linkFound);
+                    format.setAnchor(true);
+                    cursor.setCharFormat(format);
+
+                    qDebug() << "Linkified: " << linkFound;
+                }
+            }
+        }
+    } while (cursor.movePosition(QTextCursor::NextWord));
+
+
+    this->insertHtml(textDocument.toHtml() + " ");
 }
 
 
@@ -722,45 +743,97 @@ void Composer::makeLink()
     QString selectedText = this->textCursor().selectedText();
     QString link;
 
+    bool validLink = false;
+    bool dialogOk = true;
 
-    if (selectedText.isEmpty())
+    while (!validLink)
     {
-        link = QInputDialog::getText(this,
-                                     tr("Insert a link"),
-                                     tr("Type or paste a web address here.\n"
-                                        "You could also select some text first, "
-                                        "to turn it into a link.")
-                                     + "\n\n",
-                                     QLineEdit::Normal,
-                                     "http://");
-    }
-    else
-    {
-        QString shortenedText = MiscHelpers::elidedText(selectedText, 40);
+        if (selectedText.isEmpty())
+        {
+            link = QInputDialog::getText(this,
+                                         tr("Insert a link"),
+                                         tr("Type or paste a web address "
+                                            "here.\n"
+                                            "You could also select some "
+                                            "text first, to turn it into "
+                                            "a link.")
+                                         + "\n\n",
+                                         QLineEdit::Normal,
+                                         "http://",
+                                         &dialogOk);
+        }
+        else
+        {
+            QString shortenedText = MiscHelpers::elidedText(selectedText, 40);
 
-        link = QInputDialog::getText(this,
-                                     tr("Make a link from selected text"),
-                                     tr("Type or paste a web address here.\n"
-                                        "The selected text (%1) will be converted "
-                                        "to a link.").arg(shortenedText)
-                                     + "\n\n",
-                                     QLineEdit::Normal,
-                                     "http://");
-    }
+            link = QInputDialog::getText(this,
+                                         tr("Make a link from selected text"),
+                                         tr("Type or paste a web address "
+                                            "here.\n"
+                                            "The selected text (%1) will be "
+                                            "converted to a link.")
+                                         .arg("'" + shortenedText + "'")
+                                         + "\n\n",
+                                         QLineEdit::Normal,
+                                         "http://",
+                                         &dialogOk);
+        }
 
+        if (!dialogOk)
+        {
+            this->setFocus();
+            return;
+        }
 
-    if (!link.isEmpty())
-    {
         link = link.trimmed(); // Remove possible spaces before or after
 
-        this->textCursor().removeSelectedText();
-        this->insertLink(link, selectedText);
-    }
-    else
-    {
-        qDebug() << "makeLink(): Invalid URL";
+        if (link.startsWith("http://") || link.startsWith("https://")
+         || link.startsWith("ftp://")  || link.startsWith("sftp://")
+         || link.startsWith("mailto:"))
+        {
+            validLink = true;
+        }
+
+        if (!validLink)
+        {
+            int choice = QMessageBox::warning(this,
+                                              tr("Invalid link"),
+                                              tr("The text you entered does "
+                                                 "not look like a link.")
+                                              + "<br/><br/>"
+                                              + tr("It should start with "
+                                                   "one of these types:",
+                                                   "It = the link, from "
+                                                   "previous sentence")
+                                              + "<br/>"
+                                                "<ul>"
+                                                "<li>http://</li>"
+                                                "<li>https://</li>"
+                                                "<li>ftp://</li>"
+                                                "<li>sftp://</li>"
+                                                "<li>mailto:</li>"
+                                                "</ul>"
+                                                "<br/><br/><br/>",
+                                              tr("&Use it anyway"),
+                                              tr("&Enter it again"),
+                                              tr("&Cancel link"),
+                                              1, 2);
+            if (choice == 0)
+            {
+                validLink = true;
+            }
+            else if (choice == 2)
+            {
+                this->setFocus();
+                return;
+            }
+        }
     }
 
+    this->textCursor().removeSelectedText();
+    this->insertLink(link, selectedText);
+
+
     this->setFocus();
 }
 
@@ -789,7 +862,8 @@ void Composer::insertImage()
         if (imageUrl.startsWith("http://")
          || imageUrl.startsWith("https://"))
         {
-            this->insertHtml("<img src=\"" + imageUrl + "\" />");
+            this->insertHtml("<img src=\"" + imageUrl + "\" />"
+                             "<br/><br/>");
         }
         else
         {
@@ -894,8 +968,10 @@ void Composer::cancelPost()
     {
         cancelConfirmed = QMessageBox::question(this,
                                                 tr("Cancel message?"),
-                                                tr("Are you sure you want to cancel this message?"),
-                                                tr("&Yes, cancel it"), tr("&No"),
+                                                tr("Are you sure you want to "
+                                                   "cancel this message?"),
+                                                tr("&Yes, cancel it"),
+                                                tr("&No"),
                                                 "", 1, 1);
 
     }
