@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -63,6 +63,20 @@ public:
                  QWidget *parent);
     ~ConfigDialog();
 
+    void createGeneralPage(int updateInterval,
+                           int tabsPosition,
+                           bool tabsMovable);
+    void createFontsPage();
+    void createColorsPage();
+    void createTimelinesPage();
+    void createPostsPage();
+    void createComposerPage();
+    void createPrivacyPage();
+    void createNotificationsPage(QSettings *settings);
+    void createSystrayPage(QSettings *settings);
+
+    QComboBox *newAvatarComboBox();
+
     void syncNotifierOptions();
     QString checkNotifications(int notificationStyle);
     void setPublicPosts(bool value);
@@ -138,26 +152,28 @@ private:
     QSpinBox *postsPerPageMainSpinbox;
     QSpinBox *postsPerPageOtherSpinbox;
 
-    QComboBox *minorFeedSnippetsCombobox;
-    QSpinBox *snippetLimitSpinbox;
-
     QCheckBox *showDeletedCheckbox;
     QCheckBox *hideDuplicatesCheckbox;
-
     QCheckBox *jumpToNewCheckbox;
 
+    QComboBox *minorFeedSnippetsCombobox;
+    QSpinBox *snippetLimitSpinbox;
+    QComboBox *mfAvatarSizeCombobox;
+
 
     // Page 5, posts options
     QWidget *postsOptionsWidget;
     QFormLayout *postsOptionsLayout;
 
     QComboBox *postAvatarSizeCombobox;
+    QComboBox *commentAvatarSizeCombobox;
     QCheckBox *showExtendedSharesCheckbox;
     QCheckBox *showExtraInfoCheckbox;
     QCheckBox *postHLAuthorCommentsCheckbox;
     QCheckBox *postHLOwnCommentsCheckbox;
 
     QCheckBox *postIgnoreSslInImages;
+    QCheckBox *postFullImagesCheckbox;
 
 
     // Page 6, composer options
