@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -60,7 +60,7 @@ GlobalObject::GlobalObject(QObject *parent) : QObject(parent)
                << settings.value("color4", "#10BB10").toString() // Green
                << settings.value("color5").toString()
                << settings.value("color6").toString();
-    // no need to call this->syncColorSettings() now...
+    // No need to call this->syncColorSettings() now...
 
 
     ///////////////////////////////////////////////////////////////// TIMELINES
@@ -72,20 +72,23 @@ GlobalObject::GlobalObject(QObject *parent) : QObject(parent)
                           30);
     this->syncTimelinesSettings(pppMain,
                                 pppOther,
-                                settings.value("minorFeedSnippets", 0).toInt(),
-                                settings.value("snippetsCharLimit", 200).toInt(),
-                                settings.value("showDeletedPosts", false).toBool(),
-                                settings.value("hideDuplicatedPosts", false).toBool(),
-                                settings.value("jumpToNewOnUpdate", false).toBool());
+                                settings.value("showDeletedPosts",     false).toBool(),
+                                settings.value("hideDuplicatedPosts",  false).toBool(),
+                                settings.value("jumpToNewOnUpdate",    false).toBool(),
+                                settings.value("minorFeedSnippets",    0).toInt(),
+                                settings.value("snippetsCharLimit",    200).toInt(),
+                                settings.value("minorFeedAvatarIndex", 1).toInt()); // 2nd (32x32) by default
 
 
     ///////////////////////////////////////////////////////////////////// POSTS
-    this->syncPostSettings(settings.value("postAvatarSizeIndex", 2).toInt(), // 3rd (64x64) by default
+    this->syncPostSettings(settings.value("postAvatarIndex",       3).toInt(), // 4th (64x64) by default
+                           settings.value("commentAvatarIndex",    1).toInt(), // 2nd (32x32) by default
                            settings.value("postExtendedShares",    true).toBool(),
                            settings.value("postShowExtraInfo",     false).toBool(),
                            settings.value("postHLAuthorComments",  true).toBool(),
                            settings.value("postHLOwnComments",     true).toBool(),
-                           settings.value("postIgnoreSslInImages", false).toBool());
+                           settings.value("postIgnoreSslInImages", false).toBool(),
+                           settings.value("postFullImages",        false).toBool());
 
 
     ////////////////////////////////////////////////////////////////// COMPOSER
@@ -205,21 +208,22 @@ QString GlobalObject::getColor(int colorIndex)
 
 // Timeline options
 void GlobalObject::syncTimelinesSettings(int pppMain, int pppOther,
-                                         int minorFeedSnippets, int snippetsChars,
                                          bool showDeleted, bool hideDuplicates,
-                                         bool jumpToNew)
+                                         bool jumpToNew, int minorFeedSnippets,
+                                         int snippetsChars, int mfAvatarIdx)
 {
     this->postsPerPageMain = pppMain;
     this->postsPerPageOther = pppOther;
 
-    this->minorFeedSnippetsType = minorFeedSnippets;
-    this->snippetsCharLimit = snippetsChars;
-
     this->showDeletedPosts = showDeleted;
     this->hideDuplicatedPosts = hideDuplicates;
-
     this->jumpToNewOnUpdate = jumpToNew;
 
+    this->minorFeedSnippetsType = minorFeedSnippets;
+    this->snippetsCharLimit = snippetsChars;
+    this->mfAvatarIndex = mfAvatarIdx;
+    this->mfAvatarSize = this->getAvatarSizeForIndex(mfAvatarIdx);
+
     // TODO: more...
 }
 
@@ -233,16 +237,6 @@ int GlobalObject::getPostsPerPageOther()
     return this->postsPerPageOther;
 }
 
-int GlobalObject::getMinorFeedSnippetsType()
-{
-    return this->minorFeedSnippetsType;
-}
-
-int GlobalObject::getSnippetsCharLimit()
-{
-    return this->snippetsCharLimit;
-}
-
 bool GlobalObject::getShowDeleted()
 {
     return this->showDeletedPosts;
@@ -258,50 +252,50 @@ bool GlobalObject::getJumpToNewOnUpdate()
     return this->jumpToNewOnUpdate;
 }
 
+int GlobalObject::getMinorFeedSnippetsType()
+{
+    return this->minorFeedSnippetsType;
+}
+
+int GlobalObject::getSnippetsCharLimit()
+{
+    return this->snippetsCharLimit;
+}
+
+int GlobalObject::getMfAvatarIndex()
+{
+    return this->mfAvatarIndex;
+}
+
+QSize GlobalObject::getMfAvatarSize()
+{
+    return this->mfAvatarSize;
+}
+
 
 
 // Post options
-void GlobalObject::syncPostSettings(int postAvatarSizeIndex,
+void GlobalObject::syncPostSettings(int postAvatarIdx, int commentAvatarIdx,
                                     bool extendedShares, bool showExtraInfo,
                                     bool hlAuthorComments, bool hlOwnComments,
-                                    bool ignoreSslInImages)
+                                    bool ignoreSslInImages, bool fullImages)
 {
-    this->postAvatarSizeIndex = postAvatarSizeIndex;
-    int pixelSize;
-    switch (postAvatarSizeIndex)
-    {
-    case 0:
-        pixelSize = 32;
-        break;
-    // case 1 = default
-    case 2:
-        pixelSize = 64;
-        break;
-    case 3:
-        pixelSize = 96;
-        break;
-    case 4:
-        pixelSize = 128;
-        break;
-    case 5:
-        pixelSize = 256;
-        break;
+    this->postAvatarIndex = postAvatarIdx;
+    this->postAvatarSize = this->getAvatarSizeForIndex(postAvatarIdx);
+    this->commentAvatarIndex = commentAvatarIdx;
+    this->commentAvatarSize = this->getAvatarSizeForIndex(commentAvatarIdx);
 
-    default: // index = 1 or invalid option
-        pixelSize = 48;
-    }
-
-    this->postAvatarSize = QSize(pixelSize, pixelSize);
     this->postExtendedShares = extendedShares;
     this->postShowExtraInfo = showExtraInfo;
     this->postHLAuthorComments = hlAuthorComments;
     this->postHLOwnComments = hlOwnComments;
     this->postIgnoreSslInImages = ignoreSslInImages;
+    this->postFullImages = fullImages;
 }
 
-int GlobalObject::getPostAvatarSizeIndex()
+int GlobalObject::getPostAvatarIndex()
 {
-    return this->postAvatarSizeIndex;
+    return this->postAvatarIndex;
 }
 
 QSize GlobalObject::getPostAvatarSize()
@@ -309,6 +303,16 @@ QSize GlobalObject::getPostAvatarSize()
     return this->postAvatarSize;
 }
 
+int GlobalObject::getCommentAvatarIndex()
+{
+    return this->commentAvatarIndex;
+}
+
+QSize GlobalObject::getCommentAvatarSize()
+{
+    return this->commentAvatarSize;
+}
+
 bool GlobalObject::getPostExtendedShares()
 {
     return this->postExtendedShares;
@@ -334,6 +338,11 @@ bool GlobalObject::getPostIgnoreSslInImages()
     return this->postIgnoreSslInImages;
 }
 
+bool GlobalObject::getPostFullImages()
+{
+    return this->postFullImages;
+}
+
 
 // Composer options
 void GlobalObject::syncComposerSettings(bool publicPosts,
@@ -503,13 +512,19 @@ void GlobalObject::sortNickCompletionModel()
 }
 
 
-// Change status bar message in main window
+/*
+ * Change status bar message in main window
+ *
+ */
 void GlobalObject::setStatusMessage(QString message)
 {
     emit messageForStatusBar(message);
 }
 
-// Add a log message to the log viewer
+/*
+ * Add a log message to the log viewer
+ *
+ */
 void GlobalObject::logMessage(QString message, QString url)
 {
     emit messageForLog(message, url);
@@ -526,3 +541,40 @@ int GlobalObject::getTimelineHeight()
 {
     return this->timelineHeight;
 }
+
+/*
+ * Get corresponding QSize for specified index from combo box
+ *
+ */
+QSize GlobalObject::getAvatarSizeForIndex(int index)
+{
+    int pixelSize;
+
+    switch (index)
+    {
+    case 0:
+        pixelSize = 16;
+        break;
+    case 1:
+        pixelSize = 32;
+        break;
+    case 2:
+        pixelSize = 48;
+        break;
+    // case 3 = default = 64
+    case 4:
+        pixelSize = 96;
+        break;
+    case 5:
+        pixelSize = 128;
+        break;
+    case 6:
+        pixelSize = 256;
+        break;
+
+    default: // index = 3 or invalid option
+        pixelSize = 64;
+    }
+
+    return QSize(pixelSize, pixelSize);
+}
