@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -62,30 +62,36 @@ public:
 
     // Timeline options
     void syncTimelinesSettings(int pppMain, int pppOther,
-                               int minorFeedSnippets, int snippetsChars,
                                bool showDeleted, bool hideDuplicates,
-                               bool jumpToNew);
+                               bool jumpToNew, int minorFeedSnippets,
+                               int snippetsChars, int mfAvatarIdx);
     int getPostsPerPageMain();
     int getPostsPerPageOther();
-    int getMinorFeedSnippetsType();
-    int getSnippetsCharLimit();
     bool getShowDeleted();
     bool getHideDuplicates();
     bool getJumpToNewOnUpdate();
+    int getMinorFeedSnippetsType();
+    int getSnippetsCharLimit();
+    int getMfAvatarIndex();
+    QSize getMfAvatarSize();
 
 
 
     // Post options
-    void syncPostSettings(int postAvatarSizeIndex, bool extendedShares,
-                          bool showExtraInfo, bool hlAuthorComments,
-                          bool hlOwnComments, bool postIgnoreSslInImages);
-    int getPostAvatarSizeIndex();
+    void syncPostSettings(int postAvatarIdx, int commentAvatarIdx,
+                          bool extendedShares, bool showExtraInfo,
+                          bool hlAuthorComments, bool hlOwnComments,
+                          bool postIgnoreSslInImages, bool fullImages);
+    int getPostAvatarIndex();
     QSize getPostAvatarSize();
+    int getCommentAvatarIndex();
+    QSize getCommentAvatarSize();
     bool getPostExtendedShares();
     bool getPostShowExtraInfo();
     bool getPostHLAuthorComments();
     bool getPostHLOwnComments();
     bool getPostIgnoreSslInImages();
+    bool getPostFullImages();
 
 
     // Composer options
@@ -138,6 +144,8 @@ public:
     void storeTimelineHeight(int height);
     int getTimelineHeight();
 
+    QSize getAvatarSizeForIndex(int index);
+
 
 signals:
     void messagingModeRequested(QString id, QString name, QString url);
@@ -160,6 +168,8 @@ public slots:
 private:
     // General options
 
+    //// (not handled here yet)
+
 
     // Font options
     QString postTitleFontInfo;
@@ -175,21 +185,26 @@ private:
     // Timeline options
     int postsPerPageMain;
     int postsPerPageOther;
-    int minorFeedSnippetsType;
-    int snippetsCharLimit;
     bool showDeletedPosts;
     bool hideDuplicatedPosts;
     bool jumpToNewOnUpdate;
+    int minorFeedSnippetsType;
+    int snippetsCharLimit;
+    int mfAvatarIndex;
+    QSize mfAvatarSize;
 
 
     // Post options
-    int postAvatarSizeIndex;
+    int postAvatarIndex;
     QSize postAvatarSize;
+    int commentAvatarIndex;
+    QSize commentAvatarSize;
     bool postExtendedShares;
     bool postShowExtraInfo;
     bool postHLAuthorComments;
     bool postHLOwnComments;
     bool postIgnoreSslInImages;
+    bool postFullImages;
 
 
     // Composer options
