@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -58,11 +58,11 @@ int main(int argc, char *argv[])
 {
     QApplication dianaraApp(argc, argv);
     dianaraApp.setApplicationName("Dianara");
-    dianaraApp.setApplicationVersion("1.3.2");
+    dianaraApp.setApplicationVersion("1.3.3");
     dianaraApp.setOrganizationName("JanCoding");
     dianaraApp.setOrganizationDomain("jancoding.wordpress.com");
 
-    std::cout << QString("Dianara v%1 - JanKusanagi 2012-2015\n"
+    std::cout << QString("Dianara v%1 - JanKusanagi 2012-2016\n"
                          "https://jancoding.wordpress.com/dianara\n\n")
                         .arg(dianaraApp.applicationVersion()).toStdString();
 
@@ -114,7 +114,7 @@ int main(int argc, char *argv[])
                 std::cout << "    " << argv[0] << " [options]\n\n";
                 std::cout << "Options:\n";
                 std::cout << "    -c  --config [name]       Use a different "
-                             "configuration file\n";
+                             "configuration file and data folder\n";
                 std::cout << "    -d  --debug               Show debug messages "
                              "in the terminal\n";
                 std::cout << "        --linkcolor=[color]   Set color for "
