@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -31,6 +31,11 @@ MinorFeed::MinorFeed(PumpController::requestTypes minorFeedType,
     this->pController = pumpController;
     this->globalObj = globalObject;
     this->fChecker = filterChecker;
+
+    connect(pController, SIGNAL(minorFeedFailed(int)),
+            this, SLOT(onUpdateFailed(int)));
+
+
     this->setFrameStyle(QFrame::StyledPanel | QFrame::Sunken);
     this->setContentsMargins(0, 0, 0, 0);
 
@@ -666,6 +671,15 @@ void MinorFeed::setFeedContents(QVariantList activitiesList,
 }
 
 
+void MinorFeed::onUpdateFailed(int requestType)
+{
+    if (requestType == this->feedType)
+    {
+        this->getOlderButton->setEnabled(true);
+    }
+}
+
+
 void MinorFeed::decreaseNewItemsCount(bool wasHighlighted)
 {
     --unreadItemsCount;
