@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -51,7 +51,7 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
     avatarButton = new AvatarButton(activity->author(),
                                     this->pController,
                                     this->globalObj,
-                                    QSize(32,32),
+                                    this->globalObj->getMfAvatarSize(),
                                     this);
 
 
@@ -250,7 +250,7 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
             && activity->object()->getDeletedTime().isEmpty())
        )
     {
-        this->openButton = new QPushButton("+");
+        this->openButton = new QPushButton("+", this);
         openButton->setSizePolicy(QSizePolicy::Ignored,
                                   QSizePolicy::Maximum);
         openButton->setToolTip("<b></b>"
@@ -281,7 +281,7 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
             this->targetAvatarButton = new AvatarButton(personObject,
                                                         this->pController,
                                                         this->globalObj,
-                                                        QSize(28,28),
+                                                        globalObj->getMfAvatarSize(), // QSize(28,28)
                                                         this);
             rightLowerLayout->addWidget(targetAvatarButton, 0, Qt::AlignBottom);
         }
