@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -253,6 +253,16 @@ QString MiscHelpers::fileSizeString(QString fileURI)
                            .arg(sizeUnit);
 }
 
+/*
+ * Localized resolution string
+ *
+ */
+QString MiscHelpers::resolutionString(int width, int height)
+{
+    return QString("%1 x %2").arg(QLocale::system().toString(width))
+                             .arg(QLocale::system().toString(height));
+}
+
 
 
 
