@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -29,16 +29,19 @@ PageSelector::PageSelector(QWidget *parent) : QWidget(parent)
     this->setWindowFlags(Qt::Dialog);
     this->setWindowModality(Qt::ApplicationModal);
 
+    this->initialPage = 1;
 
     // Top
     this->messageLabel = new QLabel(tr("Page number:"),
                                     this);
 
     this->pageNumberSpinbox = new QSpinBox(this);
-    pageNumberSpinbox->setRange(1, 1); // 1-totalPages, but initially 1-1
+    pageNumberSpinbox->setRange(1, 1); // 1 to totalPages, but initially 1-1
     pageNumberSpinbox->setValue(1);
     connect(pageNumberSpinbox, SIGNAL(editingFinished()),
             this, SLOT(onPageNumberEntered()));
+    connect(pageNumberSpinbox, SIGNAL(valueChanged(int)),
+            this, SLOT(toggleGoButton(int)));
 
     this->rangeLabel = new QLabel(this);
 
@@ -85,6 +88,7 @@ PageSelector::PageSelector(QWidget *parent) : QWidget(parent)
                                                       QIcon(":/images/button-next.png")),
                                      "  " + tr("&Go") + " >>  ",
                                      this);
+    goButton->setDisabled(true);
     connect(goButton, SIGNAL(clicked()),
             this, SLOT(goToPage()));
 
@@ -158,6 +162,8 @@ PageSelector::~PageSelector()
  */
 void PageSelector::showForPage(int currentPage, int totalPageCount)
 {
+    this->initialPage = currentPage;
+
     this->pageNumberSpinbox->setRange(1, totalPageCount);
     this->pageNumberSpinbox->setValue(currentPage);
 
@@ -210,3 +216,24 @@ void PageSelector::onPageNumberEntered()
     // If not, it means focus when somewhere else,
     // which also causes editingFinished() to be emitted
 }
+
+/*
+ * Enable/disable 'Go' button depending on currently selected page
+ *
+ */
+void PageSelector::toggleGoButton(int selectedPage)
+{
+    this->goButton->setDisabled(selectedPage == this->initialPage);
+}
+
+
+////////////////////////////////////////////////////////////////////////////////
+////////////////////////////////// PROTECTED ///////////////////////////////////
+////////////////////////////////////////////////////////////////////////////////
+
+
+void PageSelector::hideEvent(QHideEvent *event)
+{
+    this->goButton->setDisabled(true); // Disabled for next use of the dialog
+    event->accept();
+}
