@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -703,10 +703,26 @@ Post::Post(ASActivity *activity,
     // Get URL of post image, if it's "image" type of post
     if (this->postType == "image")
     {
-        postImageUrl = activity->object()->getImageUrl();
+        postSmallImageUrl = activity->object()->getSmallImageUrl();
+        postFullImageUrl = activity->object()->getImageUrl();
         postAttachmentPureUrl = activity->object()->getAttachmentPureUrl();
 
+        if (globalObj->getPostFullImages())
+        {
+            postImageUrl = postFullImageUrl;
+        }
+        else
+        {
+            postImageUrl = postSmallImageUrl;
+        }
+
         pendingImagesList.append(postImageUrl);
+        // TMP/FIXME: optionally autodownload the full size version
+        //            when using thumbnails in the timeline?
+
+        // Get stored size
+        this->postImageSize = QSize(activity->object()->getImageWidth(),
+                                    activity->object()->getImageHeight());
     }
 
 
@@ -747,14 +763,17 @@ Post::Post(ASActivity *activity,
     // Button to join/leave the group, if the post is the creation of a group
     if (postType == "group") // FIXME: for now, only JOIN, as we can't know if we're members yet
     {
-        this->joinLeaveButton = new QPushButton(QIcon::fromTheme("user-group-new"),
-                                                tr("Join Group"));
+        this->joinLeaveButton = new QPushButton(QIcon::fromTheme("user-group-new",
+                                                                 QIcon(":/images/list-add.png")),
+                                                tr("Join Group"),
+                                                this);
         connect(joinLeaveButton, SIGNAL(clicked()),
                 this, SLOT(joinGroup()));
         rightColumnLayout->addWidget(joinLeaveButton, 0, Qt::AlignCenter);
 
         this->groupInfoLabel = new QLabel(tr("%1 members in the group")
-                                          .arg(activity->object()->getMemberCount()));
+                                          .arg(activity->object()->getMemberCount()),
+                                          this);
 #ifdef GROUPSUPPORT
         groupInfoLabel->setText(groupInfoLabel->text()
                                 + "<br><a href=\""
@@ -1092,9 +1111,14 @@ void Post::setPostContents()
                 belowMessage = this->seeFullImageString;
             }
 
+            QString resolution = tr("Size",
+                                    "Image size (resolution)") + ": "
+                                 + MiscHelpers::resolutionString(postImageSize.width(),
+                                                                 postImageSize.height());
+
             postMediaHtml = MiscHelpers::mediaHtmlBase(this->postType,
                                                        imageCachedFilename,
-                                                       "", // Could use seeFullImageString in a "novice mode"
+                                                       resolution,
                                                        belowMessage,
                                                        imageWidth);
         }
@@ -1834,14 +1858,18 @@ void Post::setAllComments(QVariantList commentsList, QString originatingPostUrl)
 
 
 /*
- * Re-share a post
+ * Share a post.
+ *
+ * TODO: Turn this into a custom dialog allowing to select
+ *       custom recipients for the 'share' activity.
  *
  */
 void Post::sharePost()
 {
     int confirmation = QMessageBox::question(this, tr("Share post?"),
                                              tr("Do you want to share %1's post?")
-                                              .arg(this->postAuthorName),
+                                              .arg(this->postAuthorName)
+                                             + "\n\n\n",
                                              tr("&Yes, share it"), tr("&No"),
                                              "", 1, 1);
 
@@ -1943,10 +1971,20 @@ void Post::openClickedURL(QUrl url)
                                                                       this->postType,
                                                                       this->postTitle,
                                                                       this->postAttachmentPureUrl);
-        ImageViewer *viewer = new ImageViewer(url.toString(),
+
+        ImageViewer *viewer = new ImageViewer(this->postFullImageUrl,
+                                              this->postImageSize,
                                               this->postTitle,
                                               suggestedFilename,
-                                              this->postImageIsAnimated);
+                                              this->postImageIsAnimated,
+                                              this);
+        connect(pController, SIGNAL(imageStored(QString)),
+                viewer, SLOT(reloadImage(QString)));
+        connect(pController, SIGNAL(imageFailed(QString)),
+                viewer, SLOT(onImageFailed(QString)));
+
+        this->pController->enqueueImageForDownload(this->postFullImageUrl);
+
         viewer->show();
     }
     else if (url.scheme() == "attachment")
@@ -1968,7 +2006,13 @@ void Post::showHighlightedUrl(QString url)
     {
         if (url.startsWith("image:/")) // Own image:/ URL
         {
-            this->pController->showTransientMessage(this->seeFullImageString);
+            QString statusMessage = this->seeFullImageString
+                                    + " ("
+                                    + MiscHelpers::resolutionString(postImageSize.width(),
+                                                                    postImageSize.height())
+                                    + ")";
+
+            this->pController->showTransientMessage(statusMessage);
         }
         else if (url.startsWith("attachment:/"))
         {
