@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -102,6 +102,18 @@ ProfileEditor::ProfileEditor(PumpController *pumpController,
             this, SLOT(enableSaveButton()));
 
 
+    newAvatarInfoLabel = new QLabel("\n"
+                                    + tr("Changing your avatar will create a "
+                                         "post in your timeline with it.\n"
+                                         "If you delete that post your avatar "
+                                         "will be deleted too.")
+                                    + "\n",
+                                    this);
+    newAvatarInfoLabel->setWordWrap(true);
+    newAvatarInfoLabel->setAlignment(Qt::AlignCenter);
+    newAvatarInfoLabel->setFrameStyle(QFrame::Box | QFrame::Raised);
+    newAvatarInfoLabel->hide();
+
 
     saveButton = new QPushButton(QIcon::fromTheme("document-save",
                                                   QIcon(":/images/button-save.png")),
@@ -139,6 +151,7 @@ ProfileEditor::ProfileEditor(PumpController *pumpController,
 
 
     this->topLayout = new QFormLayout();
+    topLayout->setContentsMargins(0, 0, 0, 0);
     topLayout->addRow(tr("Webfinger ID"), webfingerLabel);
     topLayout->addRow(tr("E-mail"),       emailLayout);
 
@@ -152,13 +165,15 @@ ProfileEditor::ProfileEditor(PumpController *pumpController,
 
     this->bottomLayout = new QHBoxLayout();
     bottomLayout->setAlignment(Qt::AlignRight | Qt::AlignBottom);
+    bottomLayout->setContentsMargins(0, 0, 0, 0);
     bottomLayout->addWidget(saveButton);
     bottomLayout->addWidget(cancelButton);
 
 
     this->mainLayout = new QVBoxLayout();
-    mainLayout->addLayout(topLayout);
-    mainLayout->addLayout(bottomLayout);
+    mainLayout->addLayout(topLayout,     9);
+    mainLayout->addWidget(newAvatarInfoLabel);
+    mainLayout->addLayout(bottomLayout,  1);
     this->setLayout(mainLayout);
 
 
@@ -268,6 +283,7 @@ void ProfileEditor::findAvatarFile()
                                                  Qt::KeepAspectRatio,
                                                  Qt::SmoothTransformation));
             this->avatarChanged = true;
+            this->newAvatarInfoLabel->show();
             this->enableSaveButton(); // Enable, since something has been changed
         }
         else
@@ -309,6 +325,7 @@ void ProfileEditor::sendProfileData(QString newImageUrl)
                    this, SLOT(sendProfileData(QString)));
 
         this->avatarChanged = false; // For next time the dialog is shown
+        this->newAvatarInfoLabel->hide();
     }
 
     QString newFullName = this->fullNameLineEdit->text().trimmed();
@@ -347,6 +364,8 @@ void ProfileEditor::closeEvent(QCloseEvent *event)
 {
     this->saveButton->setDisabled(true); // Disabled for next time
 
+    // FIXME? Maybe avatarChanged should be set to false, and the explanation hidden here
+
     QSettings settings;
     if (settings.isWritable())
     {
