@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -117,6 +117,7 @@ public:
         UpdatePostRequest,
         UpdateCommentRequest,
 
+        CheckContactRequest,
         FollowContactRequest,
         UnfollowContactRequest,
 
@@ -250,8 +251,11 @@ signals:
     void contactListReceived(QString listType, QVariantList contactList,
                              int totalReceivedCount);
     void siteUserListReceived(QVariantList contactList, int totalItems);
+    void contactVerified(QString userId, int httpCode,
+                         bool requestTimedOut, QString serverVersion);
     void contactFollowed(ASPerson *contact);
     void contactUnfollowed(ASPerson *contact);
+    void cannotFollowNow(QString userId);
     void followingListChanged();
 
     void listsListReceived(QVariantList listsList);
@@ -272,6 +276,7 @@ signals:
                               QString nextLink, int totalItems,
                               QString url);
     void userTimelineFailed();
+    void timelineFailed(int requestType);
 
     void likesReceived(QVariantList likesList, QString originatingPostURL);
     void commentsReceived(QVariantList commentsList, QString originatingPostURL);
@@ -285,6 +290,7 @@ signals:
     void minorFeedActivityReceived(QVariantList activitiesList,
                                    QString previousLink, QString nextLink,
                                    int totalItemCount);
+    void minorFeedFailed(int requestType);
 
     void avatarPictureReceived(QByteArray pictureData, QString pictureUrl);
     void imageReceived(QByteArray pictureData, QString pictureUrl);
@@ -345,7 +351,9 @@ public slots:
     void deletePost(QString postID, QString postType);
 
     void followContact(QString address);
+    void followVerifiedContact(QString address);
     void unfollowContact(QString address);
+    void onValidationTimeout();
 
 
 private:
@@ -408,6 +416,14 @@ private:
     QMap<QString, QString> currentAudienceMap;
     QString currentPostType;
 
+
+    // For multi-step verify+follow operations
+    QNetworkReply *addressCheckReply;
+    QTimer *addressCheckTimer;
+    bool addressCheckTimedOut;
+    QString addressPendingToFollow;
+
+
     // Avatars / Images queue
     QStringList pendingAvatarsList;
     QStringList pendingImagesList;
