@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -31,6 +31,10 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
     this->globalObj = globalObject;
     this->fChecker = filterChecker;
 
+    connect(pController, SIGNAL(timelineFailed(int)),
+            this, SLOT(onUpdateFailed(int)));
+
+
     this->setMinimumSize(180, 180); // Ensure something's always visible
 
     this->favoritesTimeline = false; // Initialize
@@ -53,8 +57,8 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
     demoObjectData.insert("objectType",     "note");
     demoObjectData.insert("id",             "demo-post-id");
 
-    // Show date/time when Dianara v1.3.2 was released
-    demoObjectData.insert("published",      "2015-10-31T17:00:00Z");
+    // Show date/time when Dianara v1.3.3 was released
+    demoObjectData.insert("published",      "2016-03-21T19:00:00Z");
 
 
     QSettings settings; // FIXME: kinda tmp, until posts have "unread" status, etc.
@@ -162,6 +166,7 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
 
     this->unreadPostsCount = 0;
     this->timelineOffset = 0;
+    this->oldTimelineOffset = 0;
     this->wasOnFirstPage = true;
     this->pendingToReceiveNextTime = 0;
 
@@ -191,13 +196,19 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
                                           this);
     getNewPendingButton->setFlat(true);
     connect(getNewPendingButton, SIGNAL(clicked()),
-            this, SLOT(goToFirstPage()));
+            this, SLOT(getNewPending()));
     getNewPendingButton->hide();
 
 
     // This will hold the posts and be hidden or disabled when needed
     postsWidget = new QWidget(this);
     postsWidget->setContentsMargins(0, 0, 0, 0);
+    /*
+     * Allow focus in the post holder itself, to avoid focus going to
+     * the pagination buttons when cancelling post creation in the publisher
+     *
+     */
+    postsWidget->setFocusPolicy(Qt::StrongFocus);
     if (this->timelineType == PumpController::UserTimelineRequest)
     {
         postsWidget->hide(); // Will be shown when ready
@@ -615,6 +626,15 @@ void TimeLine::syncPostsPerPage()
     }
 }
 
+
+void TimeLine::enablePaginationButtons()
+{
+    this->firstPageButton->setEnabled(true);
+    this->currentPageButton->setEnabled(true);
+    this->updateCurrentPageNumber(); // Will re-enable prev/next buttons as needed
+}
+
+
 void TimeLine::disablePaginationButtons()
 {
     this->firstPageButton->setDisabled(true);
@@ -803,8 +823,8 @@ void TimeLine::setTimeLineContents(QVariantList postList, QString previousLink,
             this->getNewPendingButton->setText(tr("%1 more posts pending for "
                                                   "next update.")
                                                .arg(pendingToReceiveNextTime)
-                                               + "   " // 3 spaces, then a watch
-                                               + QString::fromUtf8("\342\214\232")                                               .arg(pendingToReceiveNextTime)
+                                               + "   " // 3 spaces, then an alarm clock
+                                               + QString::fromUtf8("\342\217\260")
                                                + "\n"
                                                + tr("Click here to receive "
                                                     "them now."));
@@ -1074,14 +1094,24 @@ void TimeLine::setTimeLineContents(QVariantList postList, QString previousLink,
 
     // Enable timeline again, since everything is added and drawn
     this->setEnabled(true);
-    this->firstPageButton->setEnabled(true);
-    this->currentPageButton->setEnabled(true);
-    this->updateCurrentPageNumber(); // Even when not needed, will re-enable some buttons
+    this->enablePaginationButtons();
 
     qDebug() << "setTimeLineContents() /END";
 }
 
 
+void TimeLine::onUpdateFailed(int requestType)
+{
+    if (requestType == this->timelineType)
+    {
+        this->setEnabled(true); // Just in case
+
+        this->timelineOffset = this->oldTimelineOffset;
+        this->enablePaginationButtons();
+    }
+}
+
+
 /*
  * Update data in all currently-visible posts matching the object ID sent
  * by the minor feed
@@ -1279,6 +1309,7 @@ void TimeLine::goToFirstPage()
         this->wasOnFirstPage = false;
 
         this->previousPageLink.clear();  // Full reload of newest stuff
+        this->oldTimelineOffset = this->timelineOffset;
         this->timelineOffset = 0;
 
         this->setDisabled(true); // Disable soon, to avoid wrong clicks
@@ -1316,6 +1347,7 @@ void TimeLine::goToPreviousPage()
 
     this->setDisabled(true); // Disable soon, to avoid wrong clicks
 
+    this->oldTimelineOffset = this->timelineOffset;
     this->timelineOffset -= this->postsPerPage;
     if (timelineOffset < 0)
     {
@@ -1354,6 +1386,7 @@ void TimeLine::goToNextPage()
 
     this->setDisabled(true); // Disable soon, to avoid wrong clicks
 
+    this->oldTimelineOffset = this->timelineOffset;
     this->timelineOffset += this->postsPerPage;
 
     if (!favoritesTimeline) // Not favorites, use NextLink
@@ -1387,6 +1420,7 @@ void TimeLine::goToSpecificPage(int pageNumber)
 
     this->setDisabled(true); // Disable soon, to avoid wrong clicks
 
+    this->oldTimelineOffset = this->timelineOffset;
     this->timelineOffset = (pageNumber - 1) * this->postsPerPage;
 
     /* Workaround for Pump.io core bug:
@@ -1413,6 +1447,20 @@ void TimeLine::goToSpecificPage(int pageNumber)
                          this->timelineOffset); // And use offset instead
 }
 
+/*
+ * Get newest posts that were pending, explicitly from the "get pending" button.
+ *
+ * Needed to set focus on another widget first.
+ *
+ */
+void TimeLine::getNewPending()
+{
+    // Avoid annoying focus changes when 'get pending' button is disabled
+    this->postsWidget->setFocus();
+
+    this->goToFirstPage();
+}
+
 
 void TimeLine::showPageSelector()
 {
