@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2015  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -63,6 +63,7 @@ public:
     int getTotalPosts();
     void updateCurrentPageNumber();
     void syncPostsPerPage();
+    void enablePaginationButtons();
     void disablePaginationButtons();
 
     void resizePosts(QList<Post *> postsToResize, bool resizeAll=false);
@@ -101,6 +102,7 @@ signals:
 public slots:
     void setTimeLineContents(QVariantList postList, QString previousLink,
                              QString nextLink, int totalItems);
+    void onUpdateFailed(int requestType);
 
     void updatePostsFromMinorFeed(ASObject *object);
     void addLikesFromMinorFeed(QString objectId, QString objectType,
@@ -120,6 +122,7 @@ public slots:
     void goToPreviousPage();
     void goToNextPage();
     void goToSpecificPage(int pageNumber);
+    void getNewPending();
 
     void showPageSelector();
 
@@ -170,6 +173,7 @@ private:
     bool wasOnFirstPage;
 
     int timelineOffset;
+    int oldTimelineOffset;
     int postsPerPage;
     int unreadPostsCount;
     int highlightedPostsCount;
